@@ -34,6 +34,7 @@
 #include <KMessageBox>
 #include <KSharedConfig>
 #include <KStandardGuiItem>
+#include <kwidgetsaddons_version.h>
 
 int currentXPosition;
 int currentYPosition;
@@ -375,7 +376,7 @@ bool KMouseTool::applySettings()
 
     // The drag time must be less than the dwell time
     if (dwell < drag) {
-        KMessageBox::sorry(this, i18n("The drag time must be less than or equal to the dwell time."), i18n("Invalid Value"));
+        KMessageBox::error(this, i18n("The drag time must be less than or equal to the dwell time."), i18n("Invalid Value"));
         return false;
     }
 
@@ -505,17 +506,30 @@ void KMouseTool::helpSelected()
 void KMouseTool::closeSelected()
 {
     if (newSettings()) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        int answer =
+            KMessageBox::questionTwoActionsCancel(this,
+#else
         int answer = KMessageBox::questionYesNoCancel(this,
-                                                      i18n("There are unsaved changes in the active module.\nDo you want to apply the changes before closing "
-                                                           "the configuration window or discard the changes?"),
-                                                      i18n("Closing Configuration Window"),
-                                                      KStandardGuiItem::apply(),
-                                                      KStandardGuiItem::discard(),
-                                                      KStandardGuiItem::cancel(),
-                                                      QStringLiteral("AutomaticSave"));
+#endif
+                                                  i18n("There are unsaved changes in the active module.\nDo you want to apply the changes before closing "
+                                                       "the configuration window or discard the changes?"),
+                                                  i18n("Closing Configuration Window"),
+                                                  KStandardGuiItem::apply(),
+                                                  KStandardGuiItem::discard(),
+                                                  KStandardGuiItem::cancel(),
+                                                  QStringLiteral("AutomaticSave"));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (answer == KMessageBox::PrimaryAction)
+#else
         if (answer == KMessageBox::Yes)
+#endif
             applySettings();
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        else if (answer == KMessageBox::SecondaryAction)
+#else
         else if (answer == KMessageBox::No)
+#endif
             resetSettings();
         if (answer != KMessageBox::Cancel)
             hide();
@@ -527,7 +541,11 @@ void KMouseTool::closeSelected()
 void KMouseTool::quitSelected()
 {
     if (newSettings()) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        int answer = KMessageBox::questionTwoActionsCancel(
+#else
         int answer = KMessageBox::questionYesNoCancel(
+#endif
             this,
             i18n("There are unsaved changes in the active module.\nDo you want to apply the changes before quitting KMousetool or discard the changes?"),
             i18n("Quitting KMousetool"),
@@ -535,7 +553,11 @@ void KMouseTool::quitSelected()
             KStandardGuiItem::discard(),
             KStandardGuiItem::cancel(),
             QStringLiteral("AutomaticSave"));
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        if (answer == KMessageBox::PrimaryAction)
+#else
         if (answer == KMessageBox::Yes)
+#endif
             applySettings();
         if (answer != KMessageBox::Cancel) {
             saveOptions();
